# -*- coding: utf-8 -*-
##############################################################################
#
#    Original Module for OpenERP, Open Source Management Solution
#    Copyright (C) 20014 TeMPO CONSULTING (<http://tempo-consulting.fr>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
from openerp.osv import osv, fields


class product_product(osv.Model):
    _inherit = 'product.product'
    
    _columns = {
        #'supply_ref': fields.char(u"Référence fournisseur", size=64, ),
        'sap_product_code': fields.char(u"Référence SAP", size=10, ),
        'axima_type': fields.char(u"Type interne", size=64, ),
        'import_flag': fields.char(u"Flag import", size=20, invisible=True),
        }
        
    _defaults = {
        # By default, no partner is an instructor
        #'supply_ref': False,
        'sap_product_code': False,
        'axima_type': False,
        'import_flag': False,
    }
    
    def _check_product_access(self, cr, uid, vals, ids, context=None):
        if uid == 1:
            return  # admin rights
        user = self.pool.get('res.users').browse(cr, uid, uid, context=context)
        if not user or not user.company_id:
            msg = u"Vous n'appartenez à aucune agence"
            raise osv.except_osv("Avertissement", msg)
        
        if ids:
            # from write
            
            # imported product ?
            imported = False
            products = self.browse(cr, uid, ids, context=context)
            for p in products:
                if p.import_flag and p.import_flag == 'imported':
                    imported = True
                    break
            if imported:
                msg = u"Vous n'êtes pas autorisé à modifier un" \
                    u" article de cette catégorie"
                raise osv.except_osv("Avertissement", msg)
            
            # product category must be of company
            categ_id = vals.get('categ_id', False)
            categ_ok = True
            if not categ_id:
                for p in products:
                    if p.categ_id and p.categ_id.office_code \
                        and p.categ_id.office_code != user.company_id.office_code:
                        categ_ok = False
                        break
            else:
                product_categ_r = self.pool.get('product.category').read(cr,
                    uid, categ_id, ['office_code'], context=context)
                if product_categ_r:
                    if not product_categ_r['office_code'] or (
                        product_categ_r['office_code'] and \
                        product_categ_r['office_code'] != user.company_id.office_code):
                        categ_ok = False
            if not categ_ok:
                tpl = u"Vous ne pouvez modifier qu'un article appartenant" \
                        u" à la catégorie d'article de votre agence '%s'"
                msg = tpl % (user.company_id.name, )
                raise osv.except_osv("Avertissement", msg)
        else:
            # from create              
            categ_id = vals.get('categ_id', False)
            if categ_id:
                product_categ_r = self.pool.get('product.category').read(cr,
                    uid, categ_id, ['office_code'], context=context)
                if product_categ_r:
                    if not product_categ_r['office_code'] or (
                        product_categ_r['office_code'] and \
                        product_categ_r['office_code'] != user.company_id.office_code):
                            tpl = u"Vous ne pouvez ajouter d'article que dans la" \
                                u" catégorie d'article de votre agence '%s'"
                            msg = tpl % (user.company_id.name, )
                            raise osv.except_osv("Avertissement", msg)
         
    def create(self, cr, uid, vals, context=None):
        self._check_product_access(cr, uid, vals, False, context=context)            
        return super(product_product, self).create(cr, uid, vals,
            context=context)
            
    def write(self, cr, uid, ids, vals, context=None):
        self._check_product_access(cr, uid, vals, ids, context=context)            
        return super(product_product, self).write(cr, uid, ids, vals,
            context=context)
            
    def unlink(self, cr, uid, ids, context=None):
        if uid != 1:  # admin can delete (deploy xmlrpc script, ...)
            msg = u"Vous ne pouvez pas supprimer d'article"
            raise osv.except_osv("Avertissement", msg)                    
        return super(product_product, self).unlink(cr, uid, ids,
            context=context)
            
 
class product_category(osv.Model):
    _inherit = 'product.category'

    _columns = {    
        'sap_company_code': fields.char(u"Référence SAP", size=10, ),
        'office_code': fields.char(u"Code agence", size=10, ),
    }
    
    def create(self, cr, uid, vals, context=None):
        if uid != 1:  # admin can create (deploy xmlrpc script, ...)
            msg = u"Vous ne pouvez pas créer de catégorie d'article"
            raise osv.except_osv("Avertissement", msg)          
        return super(product_category, self).create(cr, uid, vals,
            context=context)
            
    def write(self, cr, uid, ids, vals, context=None):
        if uid != 1:  # admin can write (deploy xmlrpc script, ...)
            msg = u"Vous ne pouvez pas modifier de catégorie d'article"
            raise osv.except_osv("Avertissement", msg)            
        return super(product_category, self).write(cr, uid, ids, vals,
            context=context)
            
    def unlink(self, cr, uid, ids, context=None):
        if uid != 1:  # admin can delete (deploy xmlrpc script, ...)
            msg = u"Vous ne pouvez pas supprimer de catégorie d'article"
            raise osv.except_osv("Avertissement", msg)            
        return super(product_category, self).unlink(cr, uid, ids,
            context=context)
